build_template_format_db: Build template definition format

Description Usage Arguments Value Specifications Author(s) References Examples

Description

Build template definition format.

Usage

1
build_template_format_db(format_name, format_version = "0.1.0")

Arguments

format_name

Name of the format.

format_version

Version of the format (by default 0.1.0). To know more about the definition format take a look the corresponding specification section.

Value

A list of 9 elements

Specifications

Format version

The version format is always defined with 3 numbers each separated by a dot: <major>.<minor>.<patch>. The first number (<major>) is related to a major updated. It's when you have added many new features or conceptual changes impacted whose directly to the user interface (typically the new user interface is not compatible with the previous). The second number (<minor>) is when you add functionality in a backwards-compatible manner. The third number (<patch>) is related to bug resolutions and more preciously when you make backwards-compatible bug fixes.

Author(s)

Mathieu Depetris, mathieu.depetris@ird.fr

References

https://github.com/OB7-IRD/dqassess/blob/master/R/build_template_format_db.R

Examples

1
2
3
4
# Built a template of the definition format with a version 0.1.0 (default setting)
build_format_db <- ("name_of_my_format")
# Built a template of the definition format with a version 1.0.1
build_format_db <- ("name_of_my_format", format_version = "1.0.1")

OB7-IRD/dqassess documentation built on June 6, 2019, 10 a.m.