checking_data: Validation process for data

Description Usage Arguments Value Author(s) References

Description

Validation process for data.

Usage

1
2
3
checking_data(obj, format_db, ignore_case_in_codelist = TRUE,
  report = "files", report_dir = tempdir(), text_file_sep = ";",
  text_file_dec = ".", file_name_slot)

Arguments

obj

Path of the file or R's object that contain data.

format_db

Path of the file or R's object that contain the definition format.

ignore_case_in_codelist

Ignored cases (upper or lower) in the codelist. By default yes (TRUE).

report

Selected format for the report. You could choose between files, list or both. By default files selected.

report_dir

Location of export directory for the report. By default, the function uses the temporary directory.

text_file_sep

If the argument obj is a csv file, specify here the field separator of it. By default the separator is ";".

text_file_dec

If the argument obj is a csv file, specify here the string use for decimal points. By default the decimal is ".".

file_name_slot

If the argument obj is a csv file, specify here the name of the slot. By default not provided.

Value

The function returns file(s) location or list(s) name(s) of the report element(s).

Author(s)

Mathieu Depetris, mathieu.depetris@ird.fr

References

https://github.com/OB7-IRD/dqassess/blob/master/R/checking_data.R


OB7-IRD/dqassess documentation built on June 6, 2019, 10 a.m.