dqassess: Data quality assessment

Description List of available functions Vignettes link Author(s) See Also

Description

This package contain serveral functions in order to evaluate the conformity of data against a data format description. It attempt to help on data error detection concerning for example the data structures, formats or code lists. This R package was developped within the work package 5 of the FRAMEWORK CONTRACT - MARE/2016/22 "Strengthening REgional COoperation in the area of LArge PElagic fisheries data collection" (RECOLAPE project).

List of available functions

Vignettes link

Several vignettes was made for explain the methodology behind the function and for give examples of application:

Author(s)

Mathieu Depetris, mathieu.depetris@ird.fr

Norbert Billet, norbert.billet@ifremer.fr

See Also

Useful links:


OB7-IRD/dqassess documentation built on June 6, 2019, 10 a.m.