read_format_db: Read a format file definition

Description Usage Arguments Value Author(s) References Examples

Description

Read a format file definition from an Excel file

Usage

1
read_format_db(input_file_path)

Arguments

input_file_path

Path of the Excel file.

Value

A list of elements from the format file definition.

Author(s)

Mathieu Depetris, mathieu.depetris@ird.fr

References

https://github.com/OB7-IRD/dqassess/blob/master/R/read_format_db.R

Examples

1
read_format_db <- ("path_of_the_file\\file_name.xlsx")

OB7-IRD/dqassess documentation built on June 6, 2019, 10 a.m.