Description Usage Arguments Value Specifications Author(s) References Examples
Build template definition format.
1 | build_template_format_db(format_name, format_version = "0.1.0")
|
format_name |
Name of the format. |
format_version |
Version of the format (by default 0.1.0). To know more about the definition format take a look the corresponding specification section. |
A list of 9 elements
The version format is always defined with 3 numbers each separated by a dot: <major>.<minor>.<patch>. The first number (<major>) is related to a major updated. It's when you have added many new features or conceptual changes impacted whose directly to the user interface (typically the new user interface is not compatible with the previous). The second number (<minor>) is when you add functionality in a backwards-compatible manner. The third number (<patch>) is related to bug resolutions and more preciously when you make backwards-compatible bug fixes.
Mathieu Depetris, mathieu.depetris@ird.fr
https://github.com/OB7-IRD/dqassess/blob/master/R/build_template_format_db.R
1 2 3 4 | # Built a template of the definition format with a version 0.1.0 (default setting)
build_format_db <- ("name_of_my_format")
# Built a template of the definition format with a version 1.0.1
build_format_db <- ("name_of_my_format", format_version = "1.0.1")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.