Description List of available functions Vignettes link Author(s) See Also
This package contain serveral functions in order to evaluate the conformity of data against a data format description. It attempt to help on data error detection concerning for example the data structures, formats or code lists. This R package was developped within the work package 5 of the FRAMEWORK CONTRACT - MARE/2016/22 "Strengthening REgional COoperation in the area of LArge PElagic fisheries data collection" (RECOLAPE project).
build_template_format_db
read_format_db
write_format_db_excel
checking_data
Several vignettes was made for explain the methodology behind the function and for give examples of application:
../doc/dqassess_global.html
../doc/dqassess_definition_data_format.html
../doc/dqassess_methodology.html
Mathieu Depetris, mathieu.depetris@ird.fr
Norbert Billet, norbert.billet@ifremer.fr
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.