Description Usage Arguments Value Author(s) References Examples
Read a format file definition from an Excel file
1 | read_format_db(input_file_path)
|
input_file_path |
Path of the Excel file. |
A list of elements from the format file definition.
Mathieu Depetris, mathieu.depetris@ird.fr
https://github.com/OB7-IRD/dqassess/blob/master/R/read_format_db.R
1 | read_format_db <- ("path_of_the_file\\file_name.xlsx")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.