Description Usage Arguments Value Author(s) References
Generation of a definition format in a excel file.
1 2 3 | write_format_db_excel(format_db, output_file_path_dir = tempdir(),
output_file_name = paste("formatdef", format(Sys.time(),
"%Y%m%d_%H%M%S"), sep = "_"), output_file_ext = "xlsx")
|
format_db |
Name of the R's element where is stock the format definition. |
output_file_path_dir |
Location of export directory for the format definition. By default, the function uses the temporary directory. |
output_file_name |
Name of the file exported. By default, the function use this syntax: formatdef_%Y%m%d_%H%M%S (check formats of |
output_file_ext |
Extension of the file exported. You have to choose between xlsx for Excel 2007 OOXML format, or xls for Excel 95 binary format. Be default file are exported in xlsx. |
The function return the path of the exported file.
Mathieu Depetris, mathieu.depetris@ird.fr
https://github.com/OB7-IRD/dqassess/blob/master/R/write_format_db_excel.R
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.